@@ -13,7 +13,7 @@ Player::Player(QWidget *parent) :
     reload = false;
     playing = false;
     audio = new Audio();
-    connect(audio,SIGNAL(finished()), this, SLOT(playingFinished()));
+    //connect(audio,SIGNAL(finished()), this, SLOT(playingFinished()));
 }
 
 Player::~Player()
@@ -26,7 +26,7 @@ void Player::openArticle(QString itemName, QString text)
     path = itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
 
     QStringList links;
-    QFile *articleLinks = new QFile(itemName.toLower().normalized(QString::NormalizationForm_D)+".dat");
+    QFile *articleLinks = new QFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ itemName.toLower().normalized(QString::NormalizationForm_D)+".dat");
     if (articleLinks->open(QIODevice::ReadOnly))
     {
         QDataStream out(articleLinks);   // we will serialize the data into the file
