@@ -6,7 +6,7 @@
 
 Playlists::Playlists()
 {
-    playlistFile = new QFile("playlists.dat");
+    playlistFile = new QFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/playlists.dat");
     if (playlistFile->open(QIODevice::ReadOnly))
     {
         QDataStream in(playlistFile);   // we will serialize the data into the file
